dwww Home | Manual pages | Find package

sane-teco2(5)             SANE Scanner Access Now Easy            sane-teco2(5)

NAME
       sane-teco2 - SANE backend for TECO / RELISYS scanners

DESCRIPTION
       The sane-teco2 library implements a SANE (Scanner Access Now Easy) back-
       end  that provides access to some TECO SCSI flatbed scanners. This back-
       end should be considered beta-quality software! TECO scanners  are  sold
       under various brands like Mustek, Relisys, Piotech, Primax, TRUST.  This
       backend may or may not support yours.

       The scanners that should work with this backend are:

                 Vendor Model               TECO model      status
              --------------------------- --------------  -----------
                Mustek ScanMagic 4830S      VM3575         untested
                Primax Jewel 4800           VM356A         good
                Primax Profi 9600           VM6575         basic
                Primax Profi 19200          VM6586         good
                Relisys APOLLO Express 3    VM356A         basic
                Relisys APOLLO Express 6    VM6565         good
                Relisys APOLLO Express 12   ?              untested
                Relisys AVEC II S3          VM3564         good
                Relisys AVEC Super 3        VM3575         basic
                Relisys SCORPIO Pro         VM6575         good
                Relisys SCORPIO Pro-S       VM6586         untested
                Relisys SCORPIO Super 3     VM3575         good

       For  all  these scanners, lineart and gray mode work well. However, most
       of them do not support more than a handful of resolutions in color mode.
       See the backend home page (under AUTHOR) for the exact  status  of  each
       scanner.

       Note  that  the  untested  scanner  will  not be directly supported. You
       should contact the author for that.

       The TECO VM number can usually be found at the back of the  scanner.  It
       is also part of the FCC ID.

       The  options the backend supports can either be selected through command
       line options to programs like scanimage(1) or through  GUI  elements  in
       xscanimage(1), xsane(1), quiteinsane(1) or kooka(1).

       If you have any success with a scanner not listed here, or if you notice
       any  strange behavior, please report to the backend maintainer or to the
       SANE mailing list.

OPTIONS
       Valid command line options and their syntax can be listed by using:

              scanimage --help -d teco2

       Scan Mode

       --mode Lineart|Gray|Color
              selects the basic mode of operation of the scanner.  The  Lineart
              mode is black and white only (1 bit).  Gray mode will produce 256
              levels  of gray (8 bits).  Color will produce a 24 bits color im-
              age.

       --resolution 1..600
              Selects the resolution for a scan. The scanner can do all resolu-
              tions between 1 and 600, in increments  of  1,  for  Lineart  and
              Gray.  For Color, a restricted set of resolutions are available.

              Note:  All  values  with  vertical resolution in dpi > 300 (300 x
              600) or 600 (600 x 1200) result in a  wrong  proportion  for  the
              scan.  The  proportion  can  be  adjusted with the following con-
              vert(1) command from imagemagick:
              convert -geometry (dpi/max_xdpi * 100%)x100%
              max_xdpi is for the vm3575 constant with 300 dpi e.g. 600dpi  ad-
              just with: convert -geometry 200%x100%

       --preview
              requests  a preview scan. The resolution used for that scan is 50
              dpi (for VM356A and VM6575 75 dpi) and the scan area is the maxi-
              mum allowed.  The scan mode is  user  selected.  The  default  is
              "no".

       Geometry options

       -l, -t, -x,  -y
              Control  the scan area: -l sets the top left x coordinate, -t the
              top left y coordinate, -x selects the width and -y the height  of
              the scan area. All parameters are specified in millimeters by de-
              fault.

       Enhancement options

       --custom-gamma (no custom gamma option for the VM3564 and VM356A)
              (color  mode  only) allows the user to specify a gamma table (see
              the next 3 parameters).

OPTIONS FOR COLOR MODE
       These options are valid for scan mode Color only.

       --red-gamma-table
              Can be used to download a user defined gamma table  for  the  red
              channel. The table must be 256 bytes long.

       --green-gamma-table
              Can  be used to download a user defined gamma table for the green
              channel. The table must be 256 bytes long.

       --blue-gamma-table
              Can be used to download a user defined gamma table for  the  blue
              channel. The table must be 256 bytes long.

OPTIONS ONLY FOR VM3564, VM356A, VM3575 and VM6575
       These  options  are only available for VM3564, VM356A, VM3575 and VM6575
       models.

       --white-level-r 0..64
              Selects what red radiance level  should  be  considered  "white",
              when  scanning  some  sheets  by  changing  the calibration value
              loaded into the scanner. Scale 0..64 in steps of 1.

       --white-level-g 0..64
              Selects what green radiance level should be  considered  "white",
              when  scanning  some  sheets  by  changing  the calibration value
              loaded into the scanner. Scale 0..64 in steps of 1.

       --white-level-b 0..64
              Selects what blue radiance level should  be  considered  "white",
              when  scanning  some  sheets  by  changing  the calibration value
              loaded into the scanner. Scale 0..64 in steps of 1.

CONFIGURATION FILE
       The configuration file /etc/sane.d/teco2.conf supports  only  one  item:
       the device name to use (eg /dev/scanner).

FILES
       /usr/lib/x86_64-linux-gnu/sane/libsane-teco2.a
              The static library implementing this backend.

       /usr/lib/x86_64-linux-gnu/sane/libsane-teco2.so
              The  shared library implementing this backend (present on systems
              that support dynamic loading).

ENVIRONMENT
       SANE_DEBUG_TECO2
              If the library was compiled with debug support enabled, this  en-
              vironment  variable  controls  the  debug level for this backend.
              E.g., a value of 128 requests all debug  output  to  be  printed.
              Smaller levels reduce verbosity.

       SANE_TECO2_CAL_ALGO
              Either 0 or 1. Selects the algorithm for the calibration. A value
              of  1 seems to give better scans on the VM356A, VM3575.  Feedback
              on it is welcome.  For VM3564, VM356A, VM3575, VM6575 default  1.
              For other supported types default 0.

LIMITATIONS
       The  windows  TWAIN driver has many more options than this SANE backend.
       However they are only software adjustments. This backend only implements
       what the scanner can support.

BUGS
       Plenty. Parts of this backend are still under development.

SEE ALSO
       sane(7), sane-scsi(5), scanimage(1), xscanimage(1), xsane(1)

AUTHORS
       Frank Zago
              http://www.zago.net/sane/#teco2

       The package is actively maintained by Gerard Klaver.
              http://gkall.hobby.nl/teco2.html

CREDITS
       Thanks to:

       Gerard Klaver for his relentless VM3575 testings and contributed a patch
       to support the VM3564 and VM356A.

       Mark Plowman for providing the first SCSI traces from a VM3575.

       Andreas Klaedtke for providing the first SCSI traces from a VM6586 and
       for his testing, and to Stefan von Dombrowski for his testing.

       Nicolas Peyresaubes for providing the first SCSI traces from a VM656A
       and for his testing.

       Dave Parker for testing the support for the VM6575.

       Michael Hoeller for testing the support for the VM356A.

       Christoph Hoeffner for testing the support for the VM3564 (Relisys AVEC
       II S3 firmware 1.09).

                                  14 Jul 2008                     sane-teco2(5)

Generated by dwww version 1.16 on Sat Oct 3 06:50:04 CEST 2026.